#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
from setuptools import setup,find_packages
setup(
    name="biglibrary",
    version="2.0.0",
    author="yasserbdj96",
    author_email="yasser.bdj96@gmail.com",
    description='''A package with many functions that are repeated with developers or that help improve software performance or facilitate programming.''',
    long_description_content_type="text/markdown",
    long_description=open('README.md','r').read(),
    license='''MIT License''',
    packages=find_packages(),
    project_urls={
        'Source Code': "https://github.com/yasserbdj96/hiphp",
        'Author WebSite': "https://yasserbdj96.github.io/",
        'Instagram': "https://www.instagram.com/yasserbdj96/",
    },
    install_requires=[],
    keywords=['yasserbdj96', 'python', 'biglibrary', 'center', 'lslist.'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Software Development :: Libraries :: Python Modules",
        'Topic :: Communications :: Email'
    ],
    python_requires=">=3.x.x"
)
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
import os

#start biglibrary class:
class biglibrary:
    #__init__:
    def __init__(self,**kwargs):
        try:
            self.retu=kwargs["returning"]
        except:
            pass

    #center:
    def center(self,text):
        try:
            import shutil
            ts = shutil.get_terminal_size(fallback=(120, 50))
        except:
            ts=os.get_terminal_size(0)
        w=ts.columns
        texttocenter=len(text)
        w=((w-texttocenter)/2)
        w=str(w).split(".")[0]
        text=" "*int(w)+text
        try:
            if self.retu==False:
                print(text)
            else:
                return text
        except:
            print(text)
    
    def lslist(self,lslist,separator='|'):
        lslist_final=""
        try:
            import shutil
            ts = shutil.get_terminal_size(fallback=(120, 50))
        except:
            ts=os.get_terminal_size(0)
        ss=len(max(lslist,key=len))
        n=str(ts.columns/(ss+len(separator))).split(".")[0]
        for idx,key in enumerate(lslist):
            if(idx+1)%int(n):
                lslist_final+=key+(ss-len(key))*" "+f'{separator}'
            else:
                lslist_final+=key+'\n'
        try:
            if self.retu==False:
                print(lslist_final)
            else:
                return lslist_final
        except:
            print(lslist_final)
#}END.